@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Stef Walter <stefw@collabora.co.uk>
  */
@@ -24,10 +22,11 @@
 
 #define DEBUG_FLAG GCR_DEBUG_KEY
 #include "gcr-debug.h"
-#include "gcr-oids.h"
 #include "gcr-subject-public-key.h"
 #include "gcr-types.h"
 
+#include "gcr/gcr-oids.h"
+
 #include "egg/egg-asn1x.h"
 #include "egg/egg-asn1-defs.h"
 #include "egg/egg-error.h"
