@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Stef Walter <stef@thewalter.net>
  */
@@ -24,18 +22,19 @@
 #include "config.h"
 
 #include "gcr-dbus-constants.h"
-#include "gcr-dbus-generated.h"
 #define DEBUG_FLAG GCR_DEBUG_PROMPT
 #include "gcr-debug.h"
-#include "gcr-enum-types-base.h"
 #include "gcr-internal.h"
 #include "gcr-library.h"
-#include "gcr-marshal.h"
 #include "gcr-prompt.h"
 #include "gcr-secret-exchange.h"
 #include "gcr-system-prompter.h"
 #include "gcr-system-prompt.h"
 
+#include "gcr/gcr-dbus-generated.h"
+#include "gcr/gcr-enum-types-base.h"
+#include "gcr/gcr-marshal.h"
+
 #include "egg/egg-error.h"
 
 #include <string.h>
