@@ -15,8 +15,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   see <http://www.gnu.org/licenses/>.
 
    Author: Stef Walter <stefw@collabora.co.uk>
 */
@@ -124,10 +123,10 @@ on_name_lost (GDBusConnection *connection,
 		gtk_main_quit ();
 
 	} else if (g_strcmp0 (name, GCR_DBUS_PROMPTER_SYSTEM_BUS_NAME) == 0) {
-		acquired_system_prompter = TRUE;
+		acquired_system_prompter = FALSE;
 
 	} else if (g_strcmp0 (name, GCR_DBUS_PROMPTER_PRIVATE_BUS_NAME) == 0) {
-		acquired_private_prompter = TRUE;
+		acquired_private_prompter = FALSE;
 
 	}
 }
